pub async fn ensure_schema(conn: &Connection) -> Result<(), Error>Expand description
Ensure the embeddings schema exists in the given connection.
Safe to call multiple times (all DDL uses IF NOT EXISTS).
pub async fn ensure_schema(conn: &Connection) -> Result<(), Error>Ensure the embeddings schema exists in the given connection.
Safe to call multiple times (all DDL uses IF NOT EXISTS).