Module populate

Module populate 

Embedding population: walk symbols from the structural index and embed them.

Called after structure rebuild when embeddings.enabled = true. For incremental rebuilds, only symbols in changed files are re-embedded.

Additional source types:

Structs

PopulateStats
Result of a population run.

Constants

DEFAULT_MAX_COMMITS
Default number of recent commits to embed.

Functions

populate_commit_messages
Embed recent git commit messages.
populate_context_blocks
Embed all .normalize/context/ markdown files in the workspace.
populate_embeddings
Populate embeddings for all symbols in the index.
populate_incremental_for_paths
Incremental re-embedding for a set of changed file paths.
populate_markdown_docs
Embed all eligible markdown files in the workspace.