populate_embeddings

Function populate_embeddings 

pub async fn populate_embeddings(
    conn: &Connection,
    config: &EmbeddingsConfig,
    changed_paths: Option<&[String]>,
    head_commit: Option<&str>,
    repo_root: Option<&Path>,
    db_path: Option<&Path>,
) -> Result<PopulateStats>
Populate embeddings for all symbols in the index.

If incremental is true and changed_paths is provided, only symbols from those files are re-embedded. Otherwise all symbols are re-embedded.

db_path is the path to the SQLite database file, used to open a parallel raw connection with sqlite-vec registered for ANN virtual table operations.