open_vec_connection

Function open_vec_connection 

pub fn open_vec_connection(db_path: &Path) -> Option<VecConnection>
Register the sqlite-vec extension on a libsql::Connection by opening a raw FFI handle to the same database and registering there.

This is a convenience for the common case where you have a libsql::Connection and a db_path and want vec on a parallel handle. Returns the VecConnection if successful.